pub struct Parser<'a> { /* private fields */ }Expand description
Parses a supplied expression and returns a BoxedExpression.
Implementations
Sourceimpl<'a> Parser<'a>
impl<'a> Parser<'a>
Sourcepub fn parse(expression: &str) -> Result<Box<dyn Expression>>
pub fn parse(expression: &str) -> Result<Box<dyn Expression>>
parses the provided expression and turning it into a computation that can be applied to some source data.
Errors
Will return Err the expression is invalid.
Sourcepub fn parse_bytes(expression: &[u8]) -> Result<Box<dyn Expression>>
pub fn parse_bytes(expression: &[u8]) -> Result<Box<dyn Expression>>
parses the provided expression as bytes and turning it into a computation that can be applied to some source data.
Errors
Will return Err the expression is invalid.